import { Canvas } from '@nativescript-community/ui-canvas';
import { ImageSource, Observable } from '@nativescript/core';
import { ImageBitmapRenderingContext } from '../contexts/ImageBitmapRenderingContext';
import { OffscreenCanvasRenderingContext2D } from '../contexts/OffscreenCanvasRenderingContext2D';
class NSOffscreenCanvas extends Observable {
    constructor(width, height) {
        super();
        this._nativeContext = new Canvas(width, height);
    }
    getContext(contextId) {
        const self = this;
        let cl;
        switch (contextId) {
            case '2d':
                cl = OffscreenCanvasRenderingContext2D;
                break;
            case 'bitmaprenderer':
                cl = ImageBitmapRenderingContext;
                break;
            default:
                cl = null;
                break;
        }
        if (cl == null) {
            return null;
        }
        if (this._context != null && this._context instanceof cl) {
            return this._context;
        }
        const context = new cl();
        Object.defineProperty(context, 'canvas', {
            get() {
                return self;
            },
        });
        this._context = context;
        return context;
    }
    transferToImageBitmap() {
        return new ImageSource(this._nativeContext.getImage());
    }
    get nativeContext() {
        return this._nativeContext;
    }
    get width() {
        return this._nativeContext != null ? this._nativeContext.getWidth() : 0;
    }
    get height() {
        return this._nativeContext != null ? this._nativeContext.getHeight() : 0;
    }
}
export { NSOffscreenCanvas as OffscreenCanvas };
//# sourceMappingURL=OffscreenCanvas.js.map